==> ogre-next-2.3.3-3-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/dir_981382ac5f3a1ca3a953b14216ee58ea.js <==
var dir_981382ac5f3a1ca3a953b14216ee58ea =
[
    [ "OgreBarrier.h", "_ogre_barrier_8h.html", "_ogre_barrier_8h" ],
    [ "OgreDefaultWorkQueue.h", "_ogre_default_work_queue_8h.html", null ],
    [ "OgreDefaultWorkQueueStandard.h", "_ogre_default_work_queue_standard_8h.html", "_ogre_default_work_queue_standard_8h" ],
    [ "OgreDefaultWorkQueueTBB.h", "_ogre_default_work_queue_t_b_b_8h.html", "_ogre_default_work_queue_t_b_b_8h" ],
    [ "OgreLightweightMutex.h", "_ogre_lightweight_mutex_8h.html", "_ogre_lightweight_mutex_8h" ],
    [ "OgreThreadDefines.h", "_ogre_thread_defines_8h.html", "_ogre_thread_defines_8h" ],
    [ "OgreThreadDefinesBoost.h", "_ogre_thread_defines_boost_8h.html", "_ogre_thread_defines_boost_8h" ],
    [ "OgreThreadDefinesNone.h", "_ogre_thread_defines_none_8h.html", "_ogre_thread_defines_none_8h" ],
    [ "OgreThreadDefinesPoco.h", "_ogre_thread_defines_poco_8h.html", "_ogre_thread_defines_poco_8h" ],
    [ "OgreThreadDefinesSTD.h", "_ogre_thread_defines_s_t_d_8h.html", "_ogre_thread_defines_s_t_d_8h" ],
    [ "OgreThreadDefinesTBB.h", "_ogre_thread_defines_t_b_b_8h.html", "_ogre_thread_defines_t_b_b_8h" ],
    [ "OgreThreadHeaders.h", "_ogre_thread_headers_8h.html", null ],
    [ "OgreThreadHeadersBoost.h", "_ogre_thread_headers_boost_8h.html", null ],
    [ "OgreThreadHeadersPoco.h", "_ogre_thread_headers_poco_8h.html", null ],
    [ "OgreThreadHeadersSTD.h", "_ogre_thread_headers_s_t_d_8h.html", null ],
    [ "OgreThreadHeadersTBB.h", "_ogre_thread_headers_t_b_b_8h.html", null ],
    [ "OgreThreads.h", "_ogre_threads_8h.html", "_ogre_threads_8h" ],
    [ "OgreUniformScalableTask.h", "_ogre_uniform_scalable_task_8h.html", "_ogre_uniform_scalable_task_8h" ],
    [ "OgreWaitableEvent.h", "_ogre_waitable_event_8h.html", "_ogre_waitable_event_8h" ]
];

==> ogre-next-3.0.0-2-x86_64.pkg.tar.zst: usr/share/OGRE-Next/docs/api/html/dir_981382ac5f3a1ca3a953b14216ee58ea.js <==
var dir_981382ac5f3a1ca3a953b14216ee58ea =
[
    [ "OgreBarrier.h", "_ogre_barrier_8h.html", "_ogre_barrier_8h" ],
    [ "OgreDefaultWorkQueue.h", "_ogre_default_work_queue_8h.html", null ],
    [ "OgreDefaultWorkQueueStandard.h", "_ogre_default_work_queue_standard_8h.html", "_ogre_default_work_queue_standard_8h" ],
    [ "OgreDefaultWorkQueueTBB.h", "_ogre_default_work_queue_t_b_b_8h.html", "_ogre_default_work_queue_t_b_b_8h" ],
    [ "OgreLightweightMutex.h", "_ogre_lightweight_mutex_8h.html", "_ogre_lightweight_mutex_8h" ],
    [ "OgreSemaphore.h", "_ogre_semaphore_8h.html", "_ogre_semaphore_8h" ],
    [ "OgreThreadDefines.h", "_ogre_thread_defines_8h.html", "_ogre_thread_defines_8h" ],
    [ "OgreThreadDefinesNone.h", "_ogre_thread_defines_none_8h.html", "_ogre_thread_defines_none_8h" ],
    [ "OgreThreadDefinesPoco.h", "_ogre_thread_defines_poco_8h.html", "_ogre_thread_defines_poco_8h" ],
    [ "OgreThreadDefinesSTD.h", "_ogre_thread_defines_s_t_d_8h.html", "_ogre_thread_defines_s_t_d_8h" ],
    [ "OgreThreadDefinesTBB.h", "_ogre_thread_defines_t_b_b_8h.html", "_ogre_thread_defines_t_b_b_8h" ],
    [ "OgreThreadHeaders.h", "_ogre_thread_headers_8h.html", null ],
    [ "OgreThreadHeadersPoco.h", "_ogre_thread_headers_poco_8h.html", null ],
    [ "OgreThreadHeadersSTD.h", "_ogre_thread_headers_s_t_d_8h.html", null ],
    [ "OgreThreadHeadersTBB.h", "_ogre_thread_headers_t_b_b_8h.html", null ],
    [ "OgreThreads.h", "_ogre_threads_8h.html", "_ogre_threads_8h" ],
    [ "OgreUniformScalableTask.h", "_ogre_uniform_scalable_task_8h.html", "_ogre_uniform_scalable_task_8h" ],
    [ "OgreWaitableEvent.h", "_ogre_waitable_event_8h.html", "_ogre_waitable_event_8h" ]
];
